@@ -1,7 +1,4 @@
-#!/bin/bash
-
-# Set the path to programs
-export PATH=/bin
+#!/bin/sh
 
 # Check for differences between old config file and new one.
 # Replace old config file with new one if no user differences made
